@@ -41,6 +41,7 @@
 #include <netinet/in.h>
 #include <arpa/inet.h>
 #include <errno.h>
+#include <assert.h>
 #include <string.h>
 
 #ifdef HAVE_STDINT_H
@@ -121,6 +122,9 @@ int i, id, map_index;
 int extension_size;
 uint16_t	map_size;
 
+	assert(sizeof(netflow_v5_header_t) == NETFLOW_V5_HEADER_LENGTH);
+	assert(sizeof(netflow_v5_record_t) == NETFLOW_V5_RECORD_LENGTH);
+
 	verbose 		   = v;
 	default_sampling   = sampling;
 	overwrite_sampling = overwrite;
@@ -418,13 +422,15 @@ char		*string;
 	  			common_record->size			  = v5_output_record_size;
 
 				// v5 common fields
-	  			common_record->srcport		  = ntohs(v5_record->srcport);
-	  			common_record->dstport		  = ntohs(v5_record->dstport);
-	  			common_record->tcp_flags	  = v5_record->tcp_flags;
-	  			common_record->prot			  = v5_record->prot;
-	  			common_record->tos			  = v5_record->tos;
-	  			common_record->fwd_status 	  = 0;
-	  			common_record->reserved 	  = 0;
+	  			common_record->srcport		 = ntohs(v5_record->srcport);
+	  			common_record->dstport		 = ntohs(v5_record->dstport);
+	  			common_record->tcp_flags	 = v5_record->tcp_flags;
+	  			common_record->prot			 = v5_record->prot;
+	  			common_record->tos			 = v5_record->tos;
+	  			common_record->fwd_status 	 = 0;
+	  			common_record->nfversion	 = 5;
+	  			common_record->biFlowDir	 = 0;
+	  			common_record->flowEndReason = 0;
 
 				// v5 typed data as fixed struct v5_block
 	  			ipv4_block->srcaddr	= ntohl(v5_record->srcaddr);
@@ -661,6 +667,9 @@ char		*string;
  */
 void Init_v5_v7_output(send_peer_t *peer) {
 
+	assert(sizeof(netflow_v5_header_t) == NETFLOW_V5_HEADER_LENGTH);
+	assert(sizeof(netflow_v5_record_t) == NETFLOW_V5_RECORD_LENGTH);
+
 	v5_output_header = (netflow_v5_header_t *)peer->send_buffer;
 	v5_output_header->version 		= htons(5);
 	v5_output_header->SysUptime		= 0;
@@ -689,17 +698,21 @@ uint32_t	i, id, t1, t2;
 
 	if ( output_engine.first ) {	// first time a record is added
 		// boot time is set one day back - assuming that the start time of every flow does not start ealier
-		boot_time  			 		= (uint64_t)(master_record->first - 86400)*1000;
-		v5_output_header->unix_secs = htonl(master_record->first - 86400);
+		boot_time = (uint64_t)(master_record->first - 86400)*1000LL;
 		cnt   	 = 0;
 		output_engine.first 	 = 0;
 	}
 	if ( cnt == 0 ) {
-		peer->buff_ptr  = (void *)((pointer_addr_t)peer->send_buffer + NETFLOW_V5_HEADER_LENGTH);
-		v5_output_record = (netflow_v5_record_t *)((pointer_addr_t)v5_output_header + (pointer_addr_t)sizeof(netflow_v5_header_t));	
-		output_engine.sequence = output_engine.last_sequence + output_engine.last_count;
+		v5_output_record = (netflow_v5_record_t *)((pointer_addr_t)peer->send_buffer + NETFLOW_V5_HEADER_LENGTH);
+		peer->buff_ptr  = (void *)v5_output_record;
+		memset(peer->buff_ptr, 0, NETFLOW_V5_MAX_RECORDS * NETFLOW_V5_RECORD_LENGTH);
+
+		output_engine.sequence += output_engine.last_count;
 		v5_output_header->flow_sequence	= htonl(output_engine.sequence);
-		output_engine.last_sequence = output_engine.sequence;
+
+		uint32_t unix_secs = master_record->last + 3600;
+		v5_output_header->unix_secs = htonl(unix_secs);
+		v5_output_header->SysUptime = htonl((uint32_t)(unix_secs * 1000 - boot_time));
 	}
 
 	t1 	= (uint32_t)(1000LL * (uint64_t)master_record->first + (uint64_t)master_record->msec_first - boot_time);
@@ -724,11 +737,6 @@ uint32_t	i, id, t1, t2;
   	v5_output_record->output	= htons(master_record->output);
   	v5_output_record->src_as	= htons(master_record->srcas);
   	v5_output_record->dst_as	= htons(master_record->dstas);
-	v5_output_record->src_mask 	= 0;
-	v5_output_record->dst_mask 	= 0;
-	v5_output_record->pad1 		= 0;
-	v5_output_record->pad2 		= 0;
-  	v5_output_record->nexthop	= 0;
 
 	i = 0;
 	while ( (id = extension_map->ex_id[i]) != 0 ) {
